@@ -1,5 +1,5 @@
 from .logging import logger, timelog
-from .rules_db import Connection, Rule
+from .rules_db import Connection, Rule, get_rule
 from .entity import Entity, Doc
 from . import engines
 from .pipeline import Pipeline, PipelineStep
@@ -15,6 +15,7 @@ __all__ = (
     "Rule",
     "Scanner",
     "engines",
+    "get_rule",
     "logger",
     "timelog",
 )
