@@ -51,6 +51,11 @@ class CompositeFinder:
                 if trail == self.text[slice(last_end, last_end + len(trail))]:
                     self.push_composite(label, prefix + (trail,))
 
+            # handle singleton composites
+            label = self.engine.get_end(prefix)
+            if label:
+                self.push_composite(label, prefix)
+
         return self.composites
 
     def process_prefix(self, prefix: tuple, span: str, this: dict):
@@ -226,3 +231,17 @@ class CompositeEngine:
                 next_entities.append(entity)
 
         return next_entities
+
+    @classmethod
+    def to_pattern(cls, text: str, entities: List[Entity]):
+        """Helper function to generate pattern from text and entities."""
+        if entities:
+            last = -1
+            pattern = ""
+            for entity in entities:
+                if entity.start > last:
+                    pattern += text[max(0, last):entity.start]
+                    pattern += f"@{entity.label}"
+                    last = entity.end
+            pattern += text[last:]
+            return pattern
