@@ -4,7 +4,7 @@ from dataclasses import dataclass
 from functools import cached_property
 from typing import List, Iterable, Optional
 
-from entityscan import Rule
+from entityscan import Rule, get_rule
 
 
 class MetaDict:
@@ -71,7 +71,7 @@ class Entity:
 
     @classmethod
     def from_rule(cls, rule_id: int, text: str, start: int, end: int):
-        rule: Rule = Rule.select(lambda r: r.id == rule_id).first()
+        rule: Rule = get_rule(rule_id)
         groups = rule.get_groups(text)
         meta = {**(rule.meta or {}), **(groups or {})} or None
 
