@@ -14,6 +14,11 @@ def compile_pattern(pattern: str, case_sensitive: bool):
     return re.compile(pattern, flags=flags)
 
 
+@lru_cache()
+def get_rule(rule_id: int):
+    return Rule.select(lambda r: r.id == rule_id).first()
+
+
 class Rule(db.Entity):
     id = orm.PrimaryKey(int, auto=True)
     label = orm.Required(str)
@@ -59,6 +64,7 @@ class Connection:
 
         db.bind(**db_bind_params)
         db.generate_mapping(create_tables=create_tables)
+        self.rule_cache = lru_cache(maxsize=1000)
 
     @classmethod
     def close(cls):
@@ -70,7 +76,8 @@ class Connection:
         return Rule.select().count()
 
     @orm.db_session
-    def delete(self):
+    def clear(self):
+        get_rule.cache_clear()  # https://stackoverflow.com/a/55497384
         return Rule.select().delete()
 
 
